[Zope-CVS] CVS: Products/CompositePage/zmi - header.pt:1.2 zmi_edit.js:1.2

Shane Hathaway shane at zope.com
Thu Oct 9 17:29:17 EDT 2003


Update of /cvs-repository/Products/CompositePage/zmi
In directory cvs.zope.org:/tmp/cvs-serv9150/zmi

Modified Files:
	header.pt zmi_edit.js 
Log Message:
Added a basic CMF UI to composites.

Refactored the ZMI interface somewhat, moving common elements down.


=== Products/CompositePage/zmi/header.pt 1.1 => 1.2 ===
--- Products/CompositePage/zmi/header.pt:1.1	Fri Sep 26 17:21:07 2003
+++ Products/CompositePage/zmi/header.pt	Thu Oct  9 17:29:16 2003
@@ -4,7 +4,4 @@
   tal:attributes="href string:${root/absolute_url}/manage_page_style.css" />
 <script type="text/javascript" 
   tal:attributes="src string:${url}/zmi_edit_js"></script>
-<script type="text/javascript" tal:content="structure string:
-var zmi_transformer_url = '${url}';
-"></script>
 </tal:block>


=== Products/CompositePage/zmi/zmi_edit.js 1.1 => 1.2 ===
--- Products/CompositePage/zmi/zmi_edit.js:1.1	Fri Sep 26 17:21:07 2003
+++ Products/CompositePage/zmi/zmi_edit.js	Thu Oct  9 17:29:16 2003
@@ -1,16 +1,16 @@
 
 // ZMI-specific editing scripts.  Referenced by zmi/bottom.pt.
 // The variable "zmi_transformer_url" is provided by zmi/header.pt.
 
 function zmi_edit(element) {
   var path = escape(element.getAttribute("source_path"));
-  document.location = zmi_transformer_url + "/showElement?path=" + path;
+  document.location = transformer_url + "/showElement?path=" + path;
 }
 
 function zmi_add(target) {
   // Note that target_index is also available, but the ZMI can't
   // make use of it easily.
   var path = escape(target.getAttribute("target_path"));
-  document.location = zmi_transformer_url + "/showSlot?path=" + path;
+  document.location = transformer_url + "/showSlot?path=" + path;
 }
 
@@ -1,16 +1,16 @@
 
 // ZMI-specific editing scripts.  Referenced by zmi/bottom.pt.
-// The variable "zmi_transformer_url" is provided by zmi/header.pt.
+// The variable "transformer_url" is provided by common/header.pt.
 
 function zmi_edit(element) {




More information about the Zope-CVS mailing list